@@ -1,7 +1,8 @@
 import grtoolkit as gr 
 import sys, os
 
-parentFolder = os.path.dirname(sys.argv[0])
+# parentFolder = os.path.dirname(sys.argv[0])
+parentFolder = os.getcwd()
 # author = "tim ferris"
 
 print("Generate Quotes from Goodreads website.\n")
