@@ -136,11 +136,11 @@ def export(quotes, saveFile, enc):
 
 	for i in range(0,len(quotes)):
 		if i == 1:
-			save.write(quotes[i])
-			save.append("\n")
+			save.write(quotes[i][1:-1])
+			# save.append("\n")
 		else:
-			save.append(quotes[i],newline=True)
-			save.append("\n")
+			save.append(quotes[i][1:-1],newline=True)
+			# save.append("\n")
 
 
 
